##  Choosing Source for Synchronization
The source for synchronization determines whether SAP LeanIX or SAP Signavio will be the primary source of truth for the data during synchronization. Corresponding data in the target system are updated whenever changes occur in the source system. You can select the source from the Source drop-down menu for each mapping you define.
